@@ -5,6 +5,22 @@
  * @see_also: #GtkdocIface
  * @Image: object.png
  *
+ * > Two line
+ * > quote
+ *
+ * Offsets are time values to be added to local
+ * time to get Coordinated Universal Time (UTC) and should be
+ * <literal>"[±]hh[[:]mm[:ss]]"</literal>.  Dates are either
+ * <literal>"Jn"</literal> (Julian day with n between 1 and 365, leap
+ * years not counted), <literal>"n"</literal> (zero-based Julian day
+ * with n between 0 and 365) or <literal>"Mm.w.d"</literal> (day d
+ * (0 <= d <= 6) of week w (1 <= w <= 5) of month m (1 <= m <= 12), day
+ * 0 is a Sunday).  Times are in local wall clock time, the default is
+ * 02:00:00.
+ *
+ * <literal>lang_COUNTRY@MODIFIER</literal>
+ * <literal>lang_COUNTRY\@MODIFIER</literal>
+ *
  * This file contains non-sense code for the sole purpose of testing the docs.
  * We can link to the #GtkdocObject:otest property and the #GtkdocObject::otest
  * signal.
@@ -23,7 +39,11 @@
  * g_object_unref (myobj);
  * ]|
  *
- * # Examples #
+ * # Examples # {#examples}
+ *
+ * Here are a few examples.
+ *
+ * ## Example 1 ##
  *
  * You can also change parameters:
  * <informalexample>
@@ -31,13 +51,91 @@
  * </informalexample>
  *
  * This example serves two main purposes:
- * - testing conversion (long description
- *   follows here)
+ *
+ * - `test`ing conversion (`long description
+ *   follows here`)
+ *
  * - catching bugs
+ *
+ *   [GTK](http://www.gtk.org) ![Some image](home.png)
+ *
  * - having an example
  *
- * Nothing more to say.
+ * # Discussion
+ *
+ * This is a section with a heading without a trailing hash mark.
+ *
+ * > Do not confuse the GtkUIManager UI Definitions described here with
+ * > the similarly named <link linkend="BUILDER-UI">GtkBuilder UI
+ * > Definitions</link>.
+ *
+ * > Single line quote
+ *
+ * <orderedlist>
+ * <listitem><para>
+ * This list is here to ensure the parsing of the above list
+ * </para></listitem>
+ * <listitem><para>
+ * Doesn't change it.
+ * </para></listitem>
+ * </orderedlist>
+ *
+ * This example serves two main purposes:
+ *
+ * * testing alternate list syntax
+ *
+ *   Don't match this as a link [ style | binding ][ : <replaceable>priority</replaceable> ]
+ *
+ * * not sure if we want this one
+ *
+ *   A link <http://en.wikipedia.org/wiki/MOS_Technology_SID#Technical_details>
+ *
+ * <refsect3><title>An embedded docbook section</title>
+ * <para>Some stuff</para>
+ *
+ * - A list
+ *
+ * - Inside markup
+ *
+ * </refsect3>
+ *
+ * # Coda # {#this-is-an-id-tag}
+ *
+ * - One
+ * - Two
+ * - Three
+ *
+ * 1. This is a ordered list
+ *
+ * 1. This is a code block in a list:
+ *    |[<!-- language="C" -->
+ *    GObject *myobj;
+ *
+ *    myobj = gtkdoc_object_new();
+ *    // do something
+ *    g_object_unref (myobj);
+ *    ]|
+ *    And another:
+ *    |[<!-- language="C" -->
+ *    GObject *myobj;
+ *
+ *    myobj = gtkdoc_object_new();
+ *    /&ast; do something &ast;/
+ *    g_object_unref (myobj);
+ *    ]|
+ *
+ * 1. Really
+ *
+ *    Has a paragraph with a [link to the examples][examples].
+ *
+ * 1. Is
+ *
+ * Nothing more to say. Except one more link:
+ *
+ * <http://www.gnome.org/>
+ *
  */
+
 /**
  * SECTION:object2
  * @title: GtkdocObject2
@@ -50,9 +148,18 @@
  * =========
  *
  * All the internal details go here or not:
+ *
  * - single item list
  */
 
+/**
+ * SECTION:object3
+ * @title: GtkdocObject3
+ * @short_description: class that is mostly undocuemnted
+ *
+ * This file contains non-sense code for the sole purpose of testing the docs.
+ */
+
 #include <glib.h>
 #include <glib-object.h>
 
@@ -138,6 +245,18 @@ gboolean gtkdoc_object_fooify (GObject *self, ...) {
   return TRUE;
 }
 
+/**
+ * gtkdoc_object_do_not_use:
+ * @self: the object
+ *
+ * Test a deprecation without additional message.
+ *
+ * Deprecated: 3.10
+ */
+void gtkdoc_object_do_not_use (GObject *self) {
+
+}
+
 /* class internals */
 
 static void gtkdoc_object_get_property (GObject  *object, guint property_id,
@@ -313,3 +432,23 @@ GType gtkdoc_object2_get_type (void) {
   return type;
 }
 
+GType gtkdoc_object3_get_type (void) {
+  static GType type = 0;
+  if (type == 0) {
+    static const GTypeInfo info = {
+      (guint16)sizeof(GtkdocObject3Class),
+      NULL, // base_init
+      NULL, // base_finalize
+      NULL, // class_init
+      NULL, // class_finalize
+      NULL, // class_data
+      (guint16)sizeof(GtkdocObject3),
+      0,    // n_preallocs
+      NULL, // instance_init
+      NULL  // value_table
+    };
+    type = g_type_register_static(G_TYPE_OBJECT,"GtkdocObject3",&info,0);
+  }
+  return type;
+}
+
