@@ -7,6 +7,7 @@
 /* type macros */
 
 #define GTKDOC_TYPE_ENUM              (gtkdoc_enum_get_type ())
+#define GTKDOC_TYPE_ENUM2             (gtkdoc_enum2_get_type ())
 #define GTKDOC_TYPE_BOXED             (gtkdoc_boxed_get_type ())
 
 /**
@@ -24,7 +25,20 @@ typedef enum {
   GTKDOC_ENUM_V3
 } GtkdocEnum;
 
+/**
+ * GtkdocEnum2:
+ * @GTKDOC_ENUM2_V1: first
+ * @GTKDOC_ENUM2_V2: second
+ *
+ * Enum values for the #GtkdocEnum2 type.
+ */
+typedef enum {
+  GTKDOC_ENUM2_V1=0,
+  GTKDOC_ENUM2_V2,
+} GtkdocEnum2;
+
 GType  gtkdoc_enum_get_type(void) G_GNUC_CONST;
+GType  gtkdoc_enum2_get_type(void) G_GNUC_CONST;
 GType  gtkdoc_boxed_get_type(void) G_GNUC_CONST;
 
 
